@@ -189,8 +189,8 @@ fn query_list_proposals<PS: ProposalStore + 'static>(
                         paging: get_response_paging_info(limit, offset, &link, total_count),
                     },
                 )),
-                // Handles 2 (and catch all)
-                _ => {
+                // Handles 2
+                "2" => {
                     let proposal_responses = match proposals
                         .iter()
                         .map(resources::v2::proposals::ProposalResponse::try_from)
@@ -210,6 +210,12 @@ fn query_list_proposals<PS: ProposalStore + 'static>(
                         }),
                     )
                 }
+                _ => Ok(
+                    HttpResponse::BadRequest().json(ErrorResponse::bad_request(&format!(
+                        "Unsupported SplinterProtocolVersion: {}",
+                        protocol_version
+                    ))),
+                ),
             }
         }
         Err(err) => match err {
@@ -242,6 +248,7 @@ mod tests {
             ProposedCircuitBuilder, ProposedNodeBuilder,
         },
     };
+    use crate::public_key::PublicKey;
     use crate::rest_api::{
         actix_web_1::{RestApiBuilder, RestApiShutdownHandle},
         paging::Paging,
@@ -690,7 +697,7 @@ mod tests {
                         .build()
                         .expect("Unable to create proposed circuit"),
                 )
-                .with_requester(&[])
+                .with_requester(&PublicKey::from_bytes(vec![]))
                 .with_requester_node_id("node_id")
                 .build()
                 .expect("unable to build proposal"),
@@ -714,7 +721,7 @@ mod tests {
                         .build()
                         .expect("Unable to create proposed circuit"),
                 )
-                .with_requester(&[])
+                .with_requester(&PublicKey::from_bytes(vec![]))
                 .with_requester_node_id("node_id")
                 .build()
                 .expect("unable to build proposal"),
@@ -740,7 +747,7 @@ mod tests {
                         .build()
                         .expect("Unable to create proposed circuit"),
                 )
-                .with_requester(&[])
+                .with_requester(&PublicKey::from_bytes(vec![]))
                 .with_requester_node_id("node_id")
                 .build()
                 .expect("unable to build proposal"),
