@@ -15,9 +15,12 @@
 use actix_web::{web, HttpResponse};
 use futures::IntoFuture;
 use std::collections::HashMap;
+use std::convert::TryFrom;
 use std::convert::TryInto;
+use std::str::FromStr;
 use std::time;
 
+use crate::admin::messages::v1;
 use crate::admin::messages::AdminServiceEvent;
 #[cfg(feature = "authorization")]
 use crate::admin::rest_api::CIRCUIT_READ_PERMISSION;
@@ -25,9 +28,14 @@ use crate::admin::service::{
     AdminCommands, AdminServiceEventSubscriber, AdminServiceStatus, AdminSubscriberError,
 };
 use crate::admin::store;
+use crate::error::InvalidStateError;
 use crate::protocol;
-use crate::rest_api::actix_web_1::{
-    new_websocket_event_sender, EventSender, Method, ProtocolVersionRangeGuard, Request, Resource,
+use crate::rest_api::{
+    actix_web_1::{
+        new_websocket_event_sender, EventSender, Method, ProtocolVersionRangeGuard, Request,
+        Resource,
+    },
+    ErrorResponse,
 };
 
 pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 'static>(
@@ -61,9 +69,38 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
                 } else {
                     return Box::new(HttpResponse::BadRequest().finish().into_future());
                 };
+
+                let protocol_version = match request.headers().get("SplinterProtocolVersion") {
+                    Some(header_value) => match header_value.to_str() {
+                        Ok(protocol_version) => match u32::from_str(protocol_version) {
+                            Ok(protocol_version) => protocol_version,
+                            Err(_) => {
+                                return Box::new(
+                                    HttpResponse::BadRequest()
+                                        .json(ErrorResponse::bad_request(
+                                            "Unable to parse SplinterProtocolVersion",
+                                        ))
+                                        .into_future(),
+                                )
+                            }
+                        },
+                        Err(_) => {
+                            return Box::new(
+                                HttpResponse::BadRequest()
+                                    .json(ErrorResponse::bad_request(
+                                        "Unable to get SplinterProtocolVersion",
+                                    ))
+                                    .into_future(),
+                            )
+                        }
+                    },
+                    None => protocol::ADMIN_PROTOCOL_VERSION,
+                };
+
                 debug!(
-                    "Beginning application authorization handler registration for \"{}\"",
-                    circuit_management_type
+                    "Beginning application authorization handler registration for \"{}\" \
+                        with protocol {}",
+                    circuit_management_type, protocol_version
                 );
 
                 let mut query =
@@ -74,7 +111,7 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
                         }
                     };
 
-                let initial_events = {
+                let initial_events: Vec<JsonAdminEvent> = {
                     let (skip, last_seen_event_id) = query
                         .remove("last")
                         .map(|since_evt_id| {
@@ -89,7 +126,24 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
                     match admin_commands
                         .get_events_since(&last_seen_event_id, &circuit_management_type)
                     {
-                        Ok(events) => events.map(|event| JsonAdminEvent::from(&event)).skip(skip),
+                        Ok(events) => {
+                            match events
+                                .map(|event| JsonAdminEvent::new(&event, protocol_version))
+                                .skip(skip)
+                                .collect::<Result<Vec<JsonAdminEvent>, InvalidStateError>>()
+                            {
+                                Ok(events) => events,
+                                Err(err) => {
+                                    error!(
+                                        "Unable to load initial set of admin events for {}: {}",
+                                        &circuit_management_type, err
+                                    );
+                                    return Box::new(
+                                        HttpResponse::InternalServerError().finish().into_future(),
+                                    );
+                                }
+                            }
+                        }
                         Err(err) => {
                             error!(
                                 "Unable to load initial set of admin events for {}: {}",
@@ -103,11 +157,14 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
                 };
 
                 let request = Request::from((request, payload));
-                match new_websocket_event_sender(request, Box::new(initial_events)) {
+                match new_websocket_event_sender(request, Box::new(initial_events.into_iter())) {
                     Ok((sender, res)) => {
                         if let Err(err) = admin_commands.add_event_subscriber(
                             &circuit_management_type,
-                            Box::new(WsAdminServiceEventSubscriber { sender }),
+                            Box::new(WsAdminServiceEventSubscriber {
+                                sender,
+                                protocol_version,
+                            }),
                         ) {
                             error!("Unable to add admin event subscriber: {}", err);
                             return Box::new(
@@ -143,9 +200,38 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
             } else {
                 return Box::new(HttpResponse::BadRequest().finish().into_future());
             };
+
+            let protocol_version = match request.headers().get("SplinterProtocolVersion") {
+                Some(header_value) => match header_value.to_str() {
+                    Ok(protocol_version) => match u32::from_str(protocol_version) {
+                        Ok(protocol_version) => protocol_version,
+                        Err(_) => {
+                            return Box::new(
+                                HttpResponse::BadRequest()
+                                    .json(ErrorResponse::bad_request(
+                                        "Unable to parse SplinterProtocolVersion",
+                                    ))
+                                    .into_future(),
+                            )
+                        }
+                    },
+                    Err(_) => {
+                        return Box::new(
+                            HttpResponse::BadRequest()
+                                .json(ErrorResponse::bad_request(
+                                    "Unable to get SplinterProtocolVersion",
+                                ))
+                                .into_future(),
+                        )
+                    }
+                },
+                None => protocol::ADMIN_PROTOCOL_VERSION,
+            };
+
             debug!(
-                "Beginning application authorization handler registration for \"{}\"",
-                circuit_management_type
+                "Beginning application authorization handler registration for \"{}\" \
+                    with protocol {}",
+                circuit_management_type, protocol_version
             );
 
             let mut query =
@@ -154,7 +240,7 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
                     Err(_) => return Box::new(HttpResponse::BadRequest().finish().into_future()),
                 };
 
-            let initial_events = {
+            let initial_events: Vec<JsonAdminEvent> = {
                 let (skip, last_seen_event_id) = query
                     .remove("last")
                     .map(|since_evt_id| {
@@ -168,7 +254,24 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
 
                 match admin_commands.get_events_since(&last_seen_event_id, &circuit_management_type)
                 {
-                    Ok(events) => events.map(|event| JsonAdminEvent::from(&event)).skip(skip),
+                    Ok(events) => {
+                        match events
+                            .map(|event| JsonAdminEvent::new(&event, protocol_version))
+                            .skip(skip)
+                            .collect::<Result<Vec<JsonAdminEvent>, InvalidStateError>>()
+                        {
+                            Ok(events) => events,
+                            Err(err) => {
+                                error!(
+                                    "Unable to load initial set of admin events for {}: {}",
+                                    &circuit_management_type, err
+                                );
+                                return Box::new(
+                                    HttpResponse::InternalServerError().finish().into_future(),
+                                );
+                            }
+                        }
+                    }
                     Err(err) => {
                         error!(
                             "Unable to load initial set of admin events for {}: {}",
@@ -182,11 +285,14 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
             };
 
             let request = Request::from((request, payload));
-            match new_websocket_event_sender(request, Box::new(initial_events)) {
+            match new_websocket_event_sender(request, Box::new(initial_events.into_iter())) {
                 Ok((sender, res)) => {
                     if let Err(err) = admin_commands.add_event_subscriber(
                         &circuit_management_type,
-                        Box::new(WsAdminServiceEventSubscriber { sender }),
+                        Box::new(WsAdminServiceEventSubscriber {
+                            sender,
+                            protocol_version,
+                        }),
                     ) {
                         error!("Unable to add admin event subscriber: {}", err);
                         return Box::new(
@@ -207,11 +313,13 @@ pub fn make_application_handler_registration_route<A: AdminCommands + Clone + 's
 
 struct WsAdminServiceEventSubscriber {
     sender: EventSender<JsonAdminEvent>,
+    protocol_version: u32,
 }
 
 impl AdminServiceEventSubscriber for WsAdminServiceEventSubscriber {
     fn handle_event(&self, event: &store::AdminServiceEvent) -> Result<(), AdminSubscriberError> {
-        let json_event = JsonAdminEvent::from(event);
+        let json_event = JsonAdminEvent::new(event, self.protocol_version)
+            .map_err(|err| AdminSubscriberError::UnableToHandleEvent(err.to_string()))?;
         self.sender.send(json_event).map_err(|_| {
             debug!("Dropping admin service event and unsubscribing due to websocket being closed");
             AdminSubscriberError::Unsubscribe
@@ -219,28 +327,53 @@ impl AdminServiceEventSubscriber for WsAdminServiceEventSubscriber {
     }
 }
 
+// `timestamp` is set to the current time to allow for backward-compatibility, as the
+// `timestamp` is not used by the `AdminServiceStore`.
 #[derive(Debug, Serialize, Clone)]
 struct JsonAdminEvent {
     #[serde(serialize_with = "st_as_millis")]
     timestamp: time::SystemTime,
 
+    #[serde(skip_serializing_if = "Option::is_none")]
     #[serde(flatten)]
-    event: AdminServiceEvent,
+    event: Option<AdminServiceEvent>,
+
+    #[serde(skip_serializing_if = "Option::is_none")]
+    #[serde(alias = "event")]
+    #[serde(flatten)]
+    event_v1: Option<v1::AdminServiceEvent>,
 
     #[serde(skip_serializing_if = "Option::is_none")]
     event_id: Option<i64>,
 }
 
-// Conversion for the `JsonAdminEvent` sent to subscribers when the `AdminServiceStore` is
-// used to store admin events.
-// `timestamp` is set to the current time to allow for backward-compatibility, as the
-// `timestamp` is not used by the `AdminServiceStore`.
-impl From<&store::AdminServiceEvent> for JsonAdminEvent {
-    fn from(event: &store::AdminServiceEvent) -> Self {
-        Self {
-            timestamp: time::SystemTime::now(),
-            event: AdminServiceEvent::from(event),
-            event_id: Some(*event.event_id()),
+impl JsonAdminEvent {
+    fn new(
+        event: &store::AdminServiceEvent,
+        protocol_version: u32,
+    ) -> Result<Self, InvalidStateError> {
+        match protocol_version {
+            1 => Ok(Self {
+                timestamp: time::SystemTime::now(),
+                event: None,
+                event_v1: Some(v1::AdminServiceEvent::try_from(event).map_err(|_| {
+                    InvalidStateError::with_message(
+                        "Unable to convert store event into v1 event".into(),
+                    )
+                })?),
+                event_id: Some(*event.event_id()),
+            }),
+            // Handles 2
+            2 => Ok(Self {
+                timestamp: time::SystemTime::now(),
+                event: Some(AdminServiceEvent::from(event)),
+                event_v1: None,
+                event_id: Some(*event.event_id()),
+            }),
+            _ => Err(InvalidStateError::with_message(format!(
+                "Unsupported SplinterProtocolVersion: {}",
+                protocol_version
+            ))),
         }
     }
 }
