@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -24,6 +24,10 @@
 //! [`RegistryWriter`]: trait.RegistryWriter.html
 //! [`RwRegistry`]: trait.RwRegistry.html
 
+#[cfg(feature = "registry-client")]
+pub mod client;
+#[cfg(feature = "diesel")]
+mod diesel;
 mod error;
 #[cfg(feature = "rest-api")]
 mod rest_api;
@@ -33,27 +37,29 @@ mod yaml;
 use std::collections::HashMap;
 use std::iter::ExactSizeIterator;
 
+#[cfg(feature = "diesel")]
+pub use self::diesel::DieselRegistry;
 pub use error::{InvalidNodeError, RegistryError};
 pub use unified::UnifiedRegistry;
-pub use yaml::LocalYamlRegistry;
+pub use yaml::{LocalYamlRegistry, YamlNode};
 #[cfg(feature = "registry-remote")]
 pub use yaml::{RemoteYamlRegistry, RemoteYamlShutdownHandle};
 
 /// Native representation of a node in a registry.
-#[derive(Debug, Serialize, Deserialize, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq)]
 pub struct Node {
     /// The Splinter identity of the node; must be non-empty and unique in the registry.
-    pub identity: String,
+    identity: String,
     /// The endpoints the node can be reached at; at least one endpoint must be provided, and each
     /// endpoint must be non-empty and unique in the registry.
-    pub endpoints: Vec<String>,
+    endpoints: Vec<String>,
     /// A human-readable name for the node; must be non-empty.
-    pub display_name: String,
+    display_name: String,
     /// The list of public keys that are permitted to act on behalf of the node; at least one key
     /// must be provided, and each key must be non-empty.
-    pub keys: Vec<String>,
+    keys: Vec<String>,
     /// A map with node metadata.
-    pub metadata: HashMap<String, String>,
+    metadata: HashMap<String, String>,
 }
 
 impl Node {
@@ -66,6 +72,31 @@ impl Node {
     pub fn has_key(&self, key: &str) -> bool {
         self.keys.iter().any(|node_key| node_key == key)
     }
+
+    /// The Splinter identity of the node;
+    pub fn identity(&self) -> &str {
+        &self.identity
+    }
+
+    /// The endpoints the node can be reached at
+    pub fn endpoints(&self) -> &[String] {
+        &self.endpoints
+    }
+
+    /// A human-readable name for the node
+    pub fn display_name(&self) -> &str {
+        &self.display_name
+    }
+
+    /// The list of public keys that are permitted to act on behalf of the node
+    pub fn keys(&self) -> &[String] {
+        &self.keys
+    }
+
+    /// A map with node metadata.
+    pub fn metadata(&self) -> &HashMap<String, String> {
+        &self.metadata
+    }
 }
 
 /// A builder for creating new nodes.
@@ -238,7 +269,7 @@ pub trait RegistryReader: Send + Sync {
     /// # Arguments
     ///
     ///  * `identity` - The identity of the node.
-    fn fetch_node(&self, identity: &str) -> Result<Option<Node>, RegistryError>;
+    fn get_node(&self, identity: &str) -> Result<Option<Node>, RegistryError>;
 
     /// Determines whether or not the node exists in the registry.
     ///
@@ -246,19 +277,27 @@ pub trait RegistryReader: Send + Sync {
     ///
     ///  * `identity` - The identity of the node.
     fn has_node(&self, identity: &str) -> Result<bool, RegistryError> {
-        self.fetch_node(identity).map(|opt| opt.is_some())
+        self.get_node(identity).map(|opt| opt.is_some())
     }
 }
 
 /// Defines registry write capabilities.
 pub trait RegistryWriter: Send + Sync {
-    /// Adds a new node to the registry, or replaces an existing node with the same identity.
+    /// Adds a new node to the registry.
     ///
     /// # Arguments
     ///
-    /// * `node` - The node to be added to or updated in the registry.
+    /// * `node` - The node to be added to the registry.
     ///
-    fn insert_node(&self, node: Node) -> Result<(), RegistryError>;
+    fn add_node(&self, node: Node) -> Result<(), RegistryError>;
+
+    /// Replaces an existing node with the same identity.
+    ///
+    /// # Arguments
+    ///
+    /// * `node` - The node to be updated in the registry.
+    ///
+    fn update_node(&self, node: Node) -> Result<(), RegistryError>;
 
     /// Deletes a node with the given identity and returns the node if it was in the registry.
     ///
@@ -272,13 +311,6 @@ pub trait RegistryWriter: Send + Sync {
 pub trait RwRegistry: RegistryWriter + RegistryReader {
     /// Clone implementation for `RwRegistry`. The implementation of the `Clone` trait for
     /// `Box<RwRegistry>` calls this method.
-    ///
-    /// # Example
-    ///```ignore
-    ///  fn clone_box(&self) -> Box<dyn RwRegistry> {
-    ///     Box::new(self.clone())
-    ///  }
-    ///```
     fn clone_box(&self) -> Box<dyn RwRegistry>;
 
     /// Clone the `RwRegistry` as a `Box<dyn RegistryReader>`.
@@ -309,8 +341,8 @@ where
         (**self).count_nodes(predicates)
     }
 
-    fn fetch_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
-        (**self).fetch_node(identity)
+    fn get_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
+        (**self).get_node(identity)
     }
 
     fn has_node(&self, identity: &str) -> Result<bool, RegistryError> {
@@ -322,8 +354,12 @@ impl<NW> RegistryWriter for Box<NW>
 where
     NW: RegistryWriter + ?Sized,
 {
-    fn insert_node(&self, node: Node) -> Result<(), RegistryError> {
-        (**self).insert_node(node)
+    fn add_node(&self, node: Node) -> Result<(), RegistryError> {
+        (**self).add_node(node)
+    }
+
+    fn update_node(&self, node: Node) -> Result<(), RegistryError> {
+        (**self).update_node(node)
     }
 
     fn delete_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
